@@ -87,7 +87,9 @@ template <> constexpr inline auto UIVirtualBoxManager::qt_create_metaobjectdata<
         "WizardType",
         "sltCloseWizard",
         "sltOpenNewMachineWizard",
+        "sltOpenNewCloudMachineWizard",
         "sltOpenAddMachineDialog",
+        "sltOpenAddCloudMachineWizard",
         "sltOpenGroupNameEditor",
         "sltDisbandGroup",
         "sltOpenSettingsDialog",
@@ -236,118 +238,122 @@ template <> constexpr inline auto UIVirtualBoxManager::qt_create_metaobjectdata<
         }}),
         // Slot 'sltOpenNewMachineWizard'
         QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltOpenAddMachineDialog'
+        // Slot 'sltOpenNewCloudMachineWizard'
         QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltOpenGroupNameEditor'
+        // Slot 'sltOpenAddMachineDialog'
         QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltDisbandGroup'
+        // Slot 'sltOpenAddCloudMachineWizard'
         QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltOpenGroupNameEditor'
+        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltDisbandGroup'
+        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltOpenSettingsDialog'
-        QtMocHelpers::SlotData<void(QString, QString, const QUuid &)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::QString, 52 }, { QMetaType::QString, 53 }, { 0x80000000 | 19, 54 },
+        QtMocHelpers::SlotData<void(QString, QString, const QUuid &)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::QString, 54 }, { QMetaType::QString, 55 }, { 0x80000000 | 19, 56 },
         }}),
         // Slot 'sltOpenSettingsDialog'
-        QtMocHelpers::SlotData<void(QString, QString)>(51, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
-            { QMetaType::QString, 52 }, { QMetaType::QString, 53 },
+        QtMocHelpers::SlotData<void(QString, QString)>(53, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
+            { QMetaType::QString, 54 }, { QMetaType::QString, 55 },
         }}),
         // Slot 'sltOpenSettingsDialog'
-        QtMocHelpers::SlotData<void(QString)>(51, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
-            { QMetaType::QString, 52 },
+        QtMocHelpers::SlotData<void(QString)>(53, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
+            { QMetaType::QString, 54 },
         }}),
         // Slot 'sltOpenSettingsDialog'
-        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
         // Slot 'sltOpenSettingsDialogDefault'
-        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltCloseSettingsDialog'
-        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltOpenCloneMachineWizard'
         QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformMachineMove'
+        // Slot 'sltCloseSettingsDialog'
         QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformMachineRemove'
+        // Slot 'sltOpenCloneMachineWizard'
         QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformMachineMoveToNewGroup'
+        // Slot 'sltPerformMachineMove'
         QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformMachineMoveToSpecificGroup'
+        // Slot 'sltPerformMachineRemove'
         QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformStartOrShowMachine'
+        // Slot 'sltPerformMachineMoveToNewGroup'
         QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformStartMachine'
+        // Slot 'sltPerformMachineMoveToSpecificGroup'
         QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformStartMachineNormal'
+        // Slot 'sltPerformStartOrShowMachine'
         QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformStartMachineHeadless'
+        // Slot 'sltPerformStartMachine'
         QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformStartMachineDetachable'
+        // Slot 'sltPerformStartMachineNormal'
         QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformShowMachine'
+        // Slot 'sltPerformStartMachineHeadless'
         QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformCreateConsoleConnectionForGroup'
+        // Slot 'sltPerformStartMachineDetachable'
         QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformCreateConsoleConnectionForMachine'
+        // Slot 'sltPerformShowMachine'
         QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformDeleteConsoleConnectionForGroup'
+        // Slot 'sltPerformCreateConsoleConnectionForGroup'
         QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformDeleteConsoleConnectionForMachine'
+        // Slot 'sltPerformCreateConsoleConnectionForMachine'
         QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltCopyConsoleConnectionFingerprint'
+        // Slot 'sltPerformDeleteConsoleConnectionForGroup'
         QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformCopyCommandSerialUnix'
+        // Slot 'sltPerformDeleteConsoleConnectionForMachine'
         QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformCopyCommandSerialWindows'
+        // Slot 'sltCopyConsoleConnectionFingerprint'
         QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformCopyCommandVNCUnix'
+        // Slot 'sltPerformCopyCommandSerialUnix'
         QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformCopyCommandVNCWindows'
+        // Slot 'sltPerformCopyCommandSerialWindows'
         QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformShowLog'
+        // Slot 'sltPerformCopyCommandVNCUnix'
         QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltPerformCopyCommandVNCWindows'
+        QtMocHelpers::SlotData<void()>(78, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltPerformShowLog'
+        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltHandleConsoleLogRead'
-        QtMocHelpers::SlotData<void(const QString &, const QString &)>(78, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::QString, 79 }, { QMetaType::QString, 80 },
+        QtMocHelpers::SlotData<void(const QString &, const QString &)>(80, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::QString, 81 }, { QMetaType::QString, 82 },
         }}),
         // Slot 'sltExecuteExternalApplication'
-        QtMocHelpers::SlotData<void()>(81, 2, QMC::AccessPrivate, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(83, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltPerformDiscardMachineState'
-        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessPrivate, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(84, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltPerformPauseOrResumeMachine'
-        QtMocHelpers::SlotData<void(bool)>(83, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 84 },
+        QtMocHelpers::SlotData<void(bool)>(85, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 86 },
         }}),
         // Slot 'sltPerformResetMachine'
-        QtMocHelpers::SlotData<void()>(85, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformDetachMachineUI'
-        QtMocHelpers::SlotData<void()>(86, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformSaveMachineState'
         QtMocHelpers::SlotData<void()>(87, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformTerminateMachine'
+        // Slot 'sltPerformDetachMachineUI'
         QtMocHelpers::SlotData<void()>(88, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformShutdownMachine'
+        // Slot 'sltPerformSaveMachineState'
         QtMocHelpers::SlotData<void()>(89, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformPowerOffMachine'
+        // Slot 'sltPerformTerminateMachine'
         QtMocHelpers::SlotData<void()>(90, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltPerformShutdownMachine'
+        QtMocHelpers::SlotData<void()>(91, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltPerformPowerOffMachine'
+        QtMocHelpers::SlotData<void()>(92, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltHandlePoweredOffMachine'
-        QtMocHelpers::SlotData<void(bool, bool)>(91, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 92 }, { QMetaType::Bool, 93 },
+        QtMocHelpers::SlotData<void(bool, bool)>(93, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 94 }, { QMetaType::Bool, 95 },
         }}),
         // Slot 'sltPerformSwitchToMachineTool'
-        QtMocHelpers::SlotData<void(QAction *)>(94, 2, QMC::AccessPrivate, QMetaType::Void, {{
+        QtMocHelpers::SlotData<void(QAction *)>(96, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { 0x80000000 | 41, 42 },
         }}),
         // Slot 'sltPerformRefreshMachine'
-        QtMocHelpers::SlotData<void()>(95, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltShowMachineInFileManager'
-        QtMocHelpers::SlotData<void()>(96, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformCreateMachineShortcut'
         QtMocHelpers::SlotData<void()>(97, 2, QMC::AccessPrivate, QMetaType::Void),
-        // Slot 'sltPerformGroupSorting'
+        // Slot 'sltShowMachineInFileManager'
         QtMocHelpers::SlotData<void()>(98, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltPerformCreateMachineShortcut'
+        QtMocHelpers::SlotData<void()>(99, 2, QMC::AccessPrivate, QMetaType::Void),
+        // Slot 'sltPerformGroupSorting'
+        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'sltPerformMachineSearchWidgetVisibilityToggling'
-        QtMocHelpers::SlotData<void(bool)>(99, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 100 },
+        QtMocHelpers::SlotData<void(bool)>(101, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 102 },
         }}),
         // Slot 'sltPerformShowHelpBrowser'
-        QtMocHelpers::SlotData<void()>(101, 2, QMC::AccessPrivate, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(103, 2, QMC::AccessPrivate, QMetaType::Void),
     };
     QtMocHelpers::UintData qt_properties {
     };
@@ -406,54 +412,56 @@ void UIVirtualBoxManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c,
         case 32: _t->sltOpenWizard((*reinterpret_cast<std::add_pointer_t<WizardType>>(_a[1]))); break;
         case 33: _t->sltCloseWizard((*reinterpret_cast<std::add_pointer_t<WizardType>>(_a[1]))); break;
         case 34: _t->sltOpenNewMachineWizard(); break;
-        case 35: _t->sltOpenAddMachineDialog(); break;
-        case 36: _t->sltOpenGroupNameEditor(); break;
-        case 37: _t->sltDisbandGroup(); break;
-        case 38: _t->sltOpenSettingsDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[3]))); break;
-        case 39: _t->sltOpenSettingsDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
-        case 40: _t->sltOpenSettingsDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
-        case 41: _t->sltOpenSettingsDialog(); break;
-        case 42: _t->sltOpenSettingsDialogDefault(); break;
-        case 43: _t->sltCloseSettingsDialog(); break;
-        case 44: _t->sltOpenCloneMachineWizard(); break;
-        case 45: _t->sltPerformMachineMove(); break;
-        case 46: _t->sltPerformMachineRemove(); break;
-        case 47: _t->sltPerformMachineMoveToNewGroup(); break;
-        case 48: _t->sltPerformMachineMoveToSpecificGroup(); break;
-        case 49: _t->sltPerformStartOrShowMachine(); break;
-        case 50: _t->sltPerformStartMachine(); break;
-        case 51: _t->sltPerformStartMachineNormal(); break;
-        case 52: _t->sltPerformStartMachineHeadless(); break;
-        case 53: _t->sltPerformStartMachineDetachable(); break;
-        case 54: _t->sltPerformShowMachine(); break;
-        case 55: _t->sltPerformCreateConsoleConnectionForGroup(); break;
-        case 56: _t->sltPerformCreateConsoleConnectionForMachine(); break;
-        case 57: _t->sltPerformDeleteConsoleConnectionForGroup(); break;
-        case 58: _t->sltPerformDeleteConsoleConnectionForMachine(); break;
-        case 59: _t->sltCopyConsoleConnectionFingerprint(); break;
-        case 60: _t->sltPerformCopyCommandSerialUnix(); break;
-        case 61: _t->sltPerformCopyCommandSerialWindows(); break;
-        case 62: _t->sltPerformCopyCommandVNCUnix(); break;
-        case 63: _t->sltPerformCopyCommandVNCWindows(); break;
-        case 64: _t->sltPerformShowLog(); break;
-        case 65: _t->sltHandleConsoleLogRead((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
-        case 66: _t->sltExecuteExternalApplication(); break;
-        case 67: _t->sltPerformDiscardMachineState(); break;
-        case 68: _t->sltPerformPauseOrResumeMachine((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
-        case 69: _t->sltPerformResetMachine(); break;
-        case 70: _t->sltPerformDetachMachineUI(); break;
-        case 71: _t->sltPerformSaveMachineState(); break;
-        case 72: _t->sltPerformTerminateMachine(); break;
-        case 73: _t->sltPerformShutdownMachine(); break;
-        case 74: _t->sltPerformPowerOffMachine(); break;
-        case 75: _t->sltHandlePoweredOffMachine((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
-        case 76: _t->sltPerformSwitchToMachineTool((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
-        case 77: _t->sltPerformRefreshMachine(); break;
-        case 78: _t->sltShowMachineInFileManager(); break;
-        case 79: _t->sltPerformCreateMachineShortcut(); break;
-        case 80: _t->sltPerformGroupSorting(); break;
-        case 81: _t->sltPerformMachineSearchWidgetVisibilityToggling((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
-        case 82: _t->sltPerformShowHelpBrowser(); break;
+        case 35: _t->sltOpenNewCloudMachineWizard(); break;
+        case 36: _t->sltOpenAddMachineDialog(); break;
+        case 37: _t->sltOpenAddCloudMachineWizard(); break;
+        case 38: _t->sltOpenGroupNameEditor(); break;
+        case 39: _t->sltDisbandGroup(); break;
+        case 40: _t->sltOpenSettingsDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[3]))); break;
+        case 41: _t->sltOpenSettingsDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
+        case 42: _t->sltOpenSettingsDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 43: _t->sltOpenSettingsDialog(); break;
+        case 44: _t->sltOpenSettingsDialogDefault(); break;
+        case 45: _t->sltCloseSettingsDialog(); break;
+        case 46: _t->sltOpenCloneMachineWizard(); break;
+        case 47: _t->sltPerformMachineMove(); break;
+        case 48: _t->sltPerformMachineRemove(); break;
+        case 49: _t->sltPerformMachineMoveToNewGroup(); break;
+        case 50: _t->sltPerformMachineMoveToSpecificGroup(); break;
+        case 51: _t->sltPerformStartOrShowMachine(); break;
+        case 52: _t->sltPerformStartMachine(); break;
+        case 53: _t->sltPerformStartMachineNormal(); break;
+        case 54: _t->sltPerformStartMachineHeadless(); break;
+        case 55: _t->sltPerformStartMachineDetachable(); break;
+        case 56: _t->sltPerformShowMachine(); break;
+        case 57: _t->sltPerformCreateConsoleConnectionForGroup(); break;
+        case 58: _t->sltPerformCreateConsoleConnectionForMachine(); break;
+        case 59: _t->sltPerformDeleteConsoleConnectionForGroup(); break;
+        case 60: _t->sltPerformDeleteConsoleConnectionForMachine(); break;
+        case 61: _t->sltCopyConsoleConnectionFingerprint(); break;
+        case 62: _t->sltPerformCopyCommandSerialUnix(); break;
+        case 63: _t->sltPerformCopyCommandSerialWindows(); break;
+        case 64: _t->sltPerformCopyCommandVNCUnix(); break;
+        case 65: _t->sltPerformCopyCommandVNCWindows(); break;
+        case 66: _t->sltPerformShowLog(); break;
+        case 67: _t->sltHandleConsoleLogRead((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
+        case 68: _t->sltExecuteExternalApplication(); break;
+        case 69: _t->sltPerformDiscardMachineState(); break;
+        case 70: _t->sltPerformPauseOrResumeMachine((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 71: _t->sltPerformResetMachine(); break;
+        case 72: _t->sltPerformDetachMachineUI(); break;
+        case 73: _t->sltPerformSaveMachineState(); break;
+        case 74: _t->sltPerformTerminateMachine(); break;
+        case 75: _t->sltPerformShutdownMachine(); break;
+        case 76: _t->sltPerformPowerOffMachine(); break;
+        case 77: _t->sltHandlePoweredOffMachine((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
+        case 78: _t->sltPerformSwitchToMachineTool((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
+        case 79: _t->sltPerformRefreshMachine(); break;
+        case 80: _t->sltShowMachineInFileManager(); break;
+        case 81: _t->sltPerformCreateMachineShortcut(); break;
+        case 82: _t->sltPerformGroupSorting(); break;
+        case 83: _t->sltPerformMachineSearchWidgetVisibilityToggling((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 84: _t->sltPerformShowHelpBrowser(); break;
         default: ;
         }
     }
@@ -495,7 +503,7 @@ void UIVirtualBoxManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c,
                 *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
             }
             break;
-        case 76:
+        case 78:
             switch (*reinterpret_cast<int*>(_a[1])) {
             default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
             case 0:
@@ -529,14 +537,14 @@ int UIVirtualBoxManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 83)
+        if (_id < 85)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 83;
+        _id -= 85;
     }
     if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 83)
+        if (_id < 85)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 83;
+        _id -= 85;
     }
     return _id;
 }
