@@ -471,9 +471,7 @@ bool UIDesktopWidgetWatchdog::isFakeScreenDetected()
 double UIDesktopWidgetWatchdog::devicePixelRatio(int iHostScreenIndex /* = -1 */)
 {
     /* First, we should check whether the screen is valid: */
-    QScreen *pScreen = iHostScreenIndex == -1
-                     ? QGuiApplication::primaryScreen()
-                     : QGuiApplication::screens().value(iHostScreenIndex);
+    QScreen *pScreen = QGuiApplication::screens().value(iHostScreenIndex, QGuiApplication::primaryScreen());
     AssertPtrReturn(pScreen, 1.0);
 
     /* Then acquire device-pixel-ratio: */
@@ -918,15 +916,20 @@ void UIDesktopWidgetWatchdog::sltHandleHostScreenAvailableGeometryCalculated(int
             iHostScreenIndex, availableGeometry.x(), availableGeometry.y(),
             availableGeometry.width(), availableGeometry.height()));
 
-    /* Apply received data: */
-    const bool fSendSignal = m_availableGeometryData.value(iHostScreenIndex).isValid();
-    m_availableGeometryData[iHostScreenIndex] = availableGeometry;
     /* Forget finished worker: */
-    AssertPtrReturnVoid(m_availableGeometryWorkers.value(iHostScreenIndex));
-    m_availableGeometryWorkers.value(iHostScreenIndex)->disconnect();
-    m_availableGeometryWorkers.value(iHostScreenIndex)->deleteLater();
-    m_availableGeometryWorkers[iHostScreenIndex] = 0;
+    QWidget *pWorker = m_availableGeometryWorkers.value(iHostScreenIndex);
+    if (pWorker)
+    {
+        pWorker->disconnect();
+        pWorker->deleteLater();
+        m_availableGeometryWorkers[iHostScreenIndex] = 0;
+    }
 
+    /* We'll need to notify listeners if geometry recalculated (not the 1st time): */
+    const bool fSendSignal = m_availableGeometryData.value(iHostScreenIndex).isValid();
+    /* Save new geometry: */
+    if (iHostScreenIndex >= 0 && iHostScreenIndex < m_availableGeometryData.size())
+        m_availableGeometryData[iHostScreenIndex] = availableGeometry;
     /* Notify listeners: */
     if (fSendSignal)
         emit sigHostScreenWorkAreaRecalculated(iHostScreenIndex);
@@ -1059,6 +1062,9 @@ void UIDesktopWidgetWatchdog::updateHostScreenAvailableGeometry(int iHostScreenI
         AssertReturnVoid(iHostScreenIndex >= 0 && iHostScreenIndex < screenCount());
     }
 
+    /* Make sure index fits workers list bounds: */
+    AssertReturnVoid(iHostScreenIndex >= 0 && iHostScreenIndex < m_availableGeometryWorkers.size());
+
     /* Create invisible frame-less window worker: */
     UIInvisibleWindow *pWorker = new UIInvisibleWindow(iHostScreenIndex);
     AssertPtrReturnVoid(pWorker);
