@@ -862,8 +862,10 @@ void UIMiniToolBar::sltShow()
         }
         case GeometryType_Full:
         {
-            /* Show full-screen: */
-            showFullScreen();
+            /* First of all show window in normal mode
+             * then request full-screen mode async way: */
+            showNormal();
+            QTimer::singleShot(0, this, SLOT(showFullScreen()));
             break;
         }
     }
@@ -963,17 +965,19 @@ void UIMiniToolBar::sltAdjust()
         }
         case GeometryType_Full:
         {
-            /* Map window onto required screen: */
-            LogRel(("GUI:  Map mini-toolbar for window #%d to screen %d of %d\n",
-                     m_iWindowIndex, iHostScreen, qApp->screens().size()));
-            windowHandle()->setScreen(qApp->screens().at(iHostScreen));
-
             /* Set appropriate window size: */
             const QSize newSize = workingArea.size();
             LogRel(("GUI:  Resize mini-toolbar for window #%d to %dx%d\n",
                      m_iWindowIndex, newSize.width(), newSize.height()));
             resize(newSize);
 
+            /* Map/move window onto required screen: */
+            const QPoint newPosition = workingArea.topLeft();
+            LogRel(("GUI:  Map&move mini-toolbar for window #%d to screen %d of %d\n",
+                     m_iWindowIndex, iHostScreen, qApp->screens().size()));
+            windowHandle()->setScreen(qApp->screens().at(iHostScreen));
+            move(newPosition);
+
             break;
         }
     }
